@@ -7,7 +7,7 @@ use warnings;
 use Carp;
 use Moose;
 
-our $VERSION = '0.08';
+our $VERSION = 'v1.0.0';
 
 has file          => ( is => 'rw', isa => 'Str', required => 1 );
 has name          => ( is => 'rw', isa => 'Str' );
@@ -57,21 +57,39 @@ sub parse_file {
 
   open my $fh, $file or croak "Cannot open $file: $!\n";
 
-  while (<$fh>) {
-    /^Name:\s*(\S+)/         and $self->{name}      = $1;
-    /^Version:\s*(\S+)/      and $self->{version}   = $1;
-    /^Epoch:\s*(\S+)/        and $self->{epoch}     = $1;
-    /^Release:\s*(\S+)/      and $self->{release}   = $1;
-    /^Summary:\s*(.+)/       and $self->{summary}   = $1;
-    /^License:\s*(.+)/       and $self->{license}   = $1;
-    /^Group:\s*(\S+)/        and $self->{group}     = $1;
-    /^URL:\s*(\S+)/          and $self->{url}       = $1;
-    /^Source\d*:\s*(\S+)/    and push @{$self->{source}}, $1;
-    /^BuildRoot:\s*(\S+)/    and $self->{buildroot} = $1;
-    /^BuildArch:\s*(\S+)/    and $self->{buildarch} = $1;
+  my %strings = (
+    name      => qr[^Name:\s*(\S+)],
+    version   => qr[^Version:\s*(\S+)],
+    epoch     => qr[^Epoch:\s*(\S+)],
+    release   => qr[^Release:\s*(\S+)],
+    summary   => qr[^Summary:\s*(.+)],
+    license   => qr[^License:\s*(.+)],
+    group     => qr[^Group:\s*(\S+)],
+    url       => qr[^URL:\s*(\S+)],
+    buildroot => qr[^BuildRoot:\s*(\S+)],
+    buildarch => qr[^BuildArch:\s*(\S+)],
+  );
 
-    /^BuildRequires:\s*(.+)/ and push @{$self->{buildrequires}}, $1;
-    /^Requires:\s*(.+)/      and push @{$self->{requires}},      $1;
+  my %arrays = (
+    source        => qr[^Source\d*:\s*(\S+)],
+    buildrequires => qr[^BuildRequires:\s*(.+)],
+    requires      => qr[^Requires:\s*(.+)],
+  );
+
+  LINE: while (<$fh>) {
+    foreach my $attr (keys %strings) {
+      if (/$strings{$attr}/) {
+        $self->{$attr} = $1;
+        next LINE;
+      }
+    }
+
+    foreach my $attr (keys %arrays) {
+      if (/$arrays{$attr}/) {
+        push @{$self->{$attr}}, $1;
+        next LINE;
+      }
+    }
   }
 
   return $self;
@@ -105,7 +123,7 @@ Centos, SUSE, Mandriva and many more.
 RPMs are build from the source of a packages along with a spec file. The
 spec file controls how the RPM is built.
 
-This module creates Perl objects which module spec files. Currently it gives
+This module creates Perl objects which model spec files. Currently it gives
 you simple access to various pieces of information from the spec file.
 
 =head1 CAVEAT
@@ -118,7 +136,7 @@ support for the rest of the file very soon.
 
 =head2 $spec = Parse::RPM::Spec->new('some_package.spec')
 
-Creates a new Parse::EPM::Spec object. Takes one mandatory parameter which
+Creates a new Parse::RPM::Spec object. Takes one mandatory parameter which
 is the path to the spec file that you are interested in. Throws an exception
 if it doesn't find a valid spec.
 
